@@ -1,5 +1,5 @@
 package Bot::Cobalt::Core::Role::EasyAccessors;
-our $VERSION = '0.016001';
+our $VERSION = '0.016002';
 
 use strictures 1;
 use Moo::Role;
@@ -82,11 +82,11 @@ __END__
 
 =head1 NAME
 
-Bot::Cobalt::Core::Role::EasyAccessors - Easy configuration accessors
+Bot::Cobalt::Core::Role::EasyAccessors
 
 =head1 SYNOPSIS
 
-  ## Inside a Cobalt plugin:
+  ## Inside a Bot::Cobalt plugin:
   
   # Current plugin alias:
   my $current_alias = $core->get_plugin_alias($self);
@@ -102,11 +102,10 @@ Bot::Cobalt::Core::Role::EasyAccessors - Easy configuration accessors
   
 =head1 DESCRIPTION
 
-Simple methods for accessing some of the configuration state tracked by 
+L<Bot::Cobalt> core interface role providing 
+simple methods for accessing some of the configuration state tracked by 
 L<Bot::Cobalt::Core>.
 
-You might prefer L<Bot::Cobalt::Core::Sugar> when writing plugins.
-
 =head2 get_channels_cfg
 
 Returns the channel configuration hash for the specified context (or an 
